@@ -31,6 +31,7 @@ enum{
     COL_APP_ICON = 0,
     COL_APP_NAME,
     COL_DESKTOP_FILE,
+    COL_FULL_PATH,
     N_COLS
 };
 extern gboolean is_my_lock;
@@ -54,6 +55,9 @@ static void init_list_view( GtkTreeView* view )
                                          COL_APP_NAME, NULL );
 
     gtk_tree_view_append_column ( view, col );
+    
+    // add tooltip
+    gtk_tree_view_set_tooltip_column( view, COL_FULL_PATH );
 }
 
 static gint sort_by_name( GtkTreeModel *model,
@@ -69,7 +73,7 @@ static gint sort_by_name( GtkTreeModel *model,
         gtk_tree_model_get( model, b, COL_APP_NAME, &name_b, -1 );
         if ( name_b )
         {
-            ret = strcmp( name_a, name_b );
+            ret = g_ascii_strcasecmp( name_a, name_b );
             g_free( name_b );
         }
         g_free( name_a );
@@ -81,12 +85,46 @@ static void add_list_item( GtkListStore* list, VFSAppDesktop* desktop )
 {
     GtkTreeIter it;
     GdkPixbuf* icon = NULL;
+    char* file;
+    const char* name = vfs_app_desktop_get_name( desktop );
+    
+    // desktop file already in list?
+    if ( gtk_tree_model_get_iter_first( GTK_TREE_MODEL( list ), &it ) )
+    {
+        do
+        {
+            file = NULL;
+            gtk_tree_model_get( GTK_TREE_MODEL( list ), &it, COL_DESKTOP_FILE,
+                                                            &file, -1 );
+            if ( file )
+            {
+                if ( !g_strcmp0( file, name ) )
+                {
+                    // already exists
+                    g_free( file );
+                    return;
+                }
+                g_free( file );
+            }
+        }
+        while ( gtk_tree_model_iter_next( GTK_TREE_MODEL( list ), &it ) );
+    }
+
+    // tooltip
+    char* tooltip = g_markup_printf_escaped( "%s\nName=%s\nExec=%s%s",
+                                     desktop->full_path,
+                                     vfs_app_desktop_get_disp_name( desktop ),
+                                     desktop->exec,
+                                     desktop->terminal ? "\nTerminal=true" : "" );
 
     icon = vfs_app_desktop_get_icon( desktop, 20, TRUE );
     gtk_list_store_append( list, &it );
     gtk_list_store_set( list, &it, COL_APP_ICON, icon,
                         COL_APP_NAME, vfs_app_desktop_get_disp_name( desktop ),
-                        COL_DESKTOP_FILE, vfs_app_desktop_get_name( desktop ), -1 );
+                        COL_DESKTOP_FILE, vfs_app_desktop_get_name( desktop ),
+                        COL_FULL_PATH, tooltip,
+                        -1 );
+    g_free( tooltip );
     if ( icon )
         g_object_unref( icon );
 }
@@ -96,7 +134,9 @@ static GtkTreeModel* create_model_from_mime_type( VFSMimeType* mime_type )
     char** apps, **app;
     const char *type;
     GtkListStore* list = gtk_list_store_new( N_COLS, GDK_TYPE_PIXBUF,
-                                                    G_TYPE_STRING, G_TYPE_STRING );
+                                                     G_TYPE_STRING,
+                                                     G_TYPE_STRING,
+                                                     G_TYPE_STRING );
     if ( mime_type )
     {
         apps = vfs_mime_type_get_actions( mime_type );
@@ -141,8 +181,17 @@ void on_view_row_activated ( GtkTreeView *tree_view,
 }
 
 GtkWidget* app_chooser_dialog_new( GtkWindow* parent, VFSMimeType* mime_type,
-                                                        gboolean no_default )
+                                     gboolean focus_all_apps,
+                                     gboolean show_command,
+                                     gboolean show_default,
+                                     gboolean dir_default )
 {
+    /*
+    focus_all_apps      Focus All Apps tab by default
+    show_command        Show custom Command entry
+    show_default        Show 'Set as default' checkbox
+    dir_default         Show 'Set as default' also for type dir
+    */
     GtkBuilder* builder = _gtk_builder_new_from_file( PACKAGE_UI_DIR "/appchooserdlg.ui", NULL );
     GtkWidget * dlg = (GtkWidget*)gtk_builder_get_object( builder, "dlg" );
     GtkWidget* file_type = (GtkWidget*)gtk_builder_get_object( builder, "file_type" );
@@ -173,16 +222,29 @@ GtkWidget* app_chooser_dialog_new( GtkWindow* parent, VFSMimeType* mime_type,
         g_free( mime_desc );
     }
     /* Don't set default handler for directories and files with unknown type */
-    if ( no_default ||
-         0 == strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_UNKNOWN ) ||
-         0 == strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_DIRECTORY ) )
+    if ( !show_default ||
+       /*  0 == strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_UNKNOWN ) || */
+         ( 0 == strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_DIRECTORY ) &&
+           !dir_default ) )
     {
-        gtk_widget_hide( (GtkWidget*)gtk_builder_get_object( builder, "set_default" ) );
+        gtk_widget_hide( (GtkWidget*)gtk_builder_get_object( builder,
+                                                            "set_default" ) );
     }
-
-    view = GTK_TREE_VIEW( (GtkWidget*)gtk_builder_get_object( builder, "recommended_apps" ) );
-    entry = GTK_ENTRY( (GtkWidget*)gtk_builder_get_object( builder, "cmdline" ) );
-    notebook = GTK_NOTEBOOK( (GtkWidget*)gtk_builder_get_object( builder, "notebook" ) );
+    if ( !show_command )
+    {
+        gtk_widget_hide( (GtkWidget*)gtk_builder_get_object( builder,
+                                                            "hbox_command" ) );
+        gtk_label_set_text( GTK_LABEL( gtk_builder_get_object( builder,
+                                                        "label_command" ) ),
+                            _("Please choose an application:") );
+    }
+    
+    view = GTK_TREE_VIEW( (GtkWidget*)gtk_builder_get_object(
+                                            builder, "recommended_apps" ) );
+    notebook = GTK_NOTEBOOK( (GtkWidget*)gtk_builder_get_object( builder,
+                                            "notebook" ) );
+    entry = GTK_ENTRY( (GtkWidget*)gtk_builder_get_object( builder,
+                                            "cmdline" ) );
 
     model = create_model_from_mime_type( mime_type );
     gtk_tree_view_set_model( view, model );
@@ -204,7 +266,7 @@ GtkWidget* app_chooser_dialog_new( GtkWindow* parent, VFSMimeType* mime_type,
 
     gtk_window_set_transient_for( GTK_WINDOW( dlg ), parent );
     
-    if ( no_default )
+    if ( focus_all_apps )
     {
         // select All Apps tab
         gtk_widget_show( dlg );
@@ -265,7 +327,7 @@ on_notebook_switch_page ( GtkNotebook *notebook,
             gdk_cursor_unref( busy );
 
             list = gtk_list_store_new( N_COLS, GDK_TYPE_PIXBUF,
-                                       G_TYPE_STRING, G_TYPE_STRING );
+                                       G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING );
             task = vfs_async_task_new( (VFSAsyncFunc) load_all_known_apps_thread, list );
             g_object_set_data( G_OBJECT(task), "view", view );
             g_object_set_data( G_OBJECT(dlg), "task", task );
@@ -410,7 +472,7 @@ static void on_dlg_response( GtkDialog* dlg, int id, gpointer user_data )
         task = (VFSAsyncTask*)g_object_get_data( G_OBJECT(dlg), "task" );
         if( task )
         {
-printf("spacefm: app-chooser.c -> vfs_async_task_cancel\n");
+//printf("spacefm: app-chooser.c -> vfs_async_task_cancel\n");
             // see note in vfs-async-task.c: vfs_async_task_real_cancel()
             GDK_THREADS_LEAVE(); 
             vfs_async_task_cancel( task );
@@ -423,14 +485,26 @@ printf("spacefm: app-chooser.c -> vfs_async_task_cancel\n");
 }
 
 gchar* ptk_choose_app_for_mime_type( GtkWindow* parent,
-                                           VFSMimeType* mime_type,
-                                           gboolean no_default )
+                                     VFSMimeType* mime_type,
+                                     gboolean focus_all_apps,
+                                     gboolean show_command,
+                                     gboolean show_default,
+                                     gboolean dir_default )
 {
+    /*
+    focus_all_apps      Focus All Apps tab by default
+    show_command        Show custom Command entry
+    show_default        Show 'Set as default' checkbox
+    dir_default         Show 'Set as default' also for type dir
+    */
     GtkWidget * dlg;
     gchar* app = NULL;
     gchar* custom = NULL;
 
-    dlg = app_chooser_dialog_new( parent, mime_type, no_default );
+    dlg = app_chooser_dialog_new( parent, mime_type, focus_all_apps,
+                                                     show_command,
+                                                     show_default,
+                                                     dir_default );
 
     g_signal_connect( dlg, "response",  G_CALLBACK(on_dlg_response), NULL );
 
@@ -445,8 +519,11 @@ gchar* ptk_choose_app_for_mime_type( GtkWindow* parent,
             {
                 vfs_mime_type_set_default_action( mime_type, app );
             }
-            else if ( strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_UNKNOWN )
-                      && strcmp( vfs_mime_type_get_type( mime_type ), XDG_MIME_TYPE_DIRECTORY ))
+            else if (/* strcmp( vfs_mime_type_get_type( mime_type ),
+                                                    XDG_MIME_TYPE_UNKNOWN ) && */
+                    ( dir_default ||
+                      strcmp( vfs_mime_type_get_type( mime_type ),
+                                                    XDG_MIME_TYPE_DIRECTORY ) ) )
             {
                 vfs_mime_type_add_action( mime_type, app, &custom );
                 g_free( app );
