@@ -27,6 +27,8 @@
 #include "vfs-file-info.h"
 #include "vfs-file-monitor.h"
 
+#include "gtk2-compat.h"
+
 static GQuark dir_tree_view_data = 0;
 
 static GtkTreeModel* get_dir_tree_model();
@@ -94,6 +96,11 @@ on_dir_tree_view_drag_motion ( GtkWidget *widget,
                             guint time,
                             PtkFileBrowser* file_browser );
 
+static gboolean on_dir_tree_view_drag_leave ( GtkWidget *widget,
+                            GdkDragContext *drag_context,
+                            guint time,
+                            PtkFileBrowser* file_browser );
+
 static gboolean
 on_dir_tree_view_drag_drop ( GtkWidget *widget,
                             GdkDragContext *drag_context,
@@ -112,8 +119,8 @@ static gboolean filter_func( GtkTreeModel *model,
     VFSFileInfo * file;
     const char* name;
     GtkTreeView* view = ( GtkTreeView* ) data;
-    gboolean show_hidden = ( gboolean ) g_object_get_qdata( G_OBJECT( view ),
-                                                            dir_tree_view_data );
+    gboolean show_hidden = GPOINTER_TO_INT( g_object_get_qdata( G_OBJECT( view ),
+                                                            dir_tree_view_data ) );
 
     if ( show_hidden )
         return TRUE;
@@ -150,9 +157,7 @@ GtkWidget* ptk_dir_tree_view_new( PtkFileBrowser* browser,
 
     dir_tree_view = GTK_TREE_VIEW( gtk_tree_view_new () );
     gtk_tree_view_set_headers_visible( dir_tree_view, FALSE );
-#if GTK_CHECK_VERSION(2, 10, 0)
     gtk_tree_view_set_enable_tree_lines(dir_tree_view, TRUE);
-#endif
     
 //MOD enabled DND   FIXME: Temporarily disable drag & drop since it doesn't work right now.
 /*    exo_icon_view_enable_model_drag_dest (
@@ -188,7 +193,7 @@ GtkWidget* ptk_dir_tree_view_new( PtkFileBrowser* browser,
     if ( G_UNLIKELY( !dir_tree_view_data ) )
         dir_tree_view_data = g_quark_from_static_string( "show_hidden" );
     g_object_set_qdata( G_OBJECT( dir_tree_view ),
-                        dir_tree_view_data, ( gpointer ) show_hidden );
+                        dir_tree_view_data, GINT_TO_POINTER( show_hidden ) );
     model = get_dir_tree_model();
     filter = gtk_tree_model_filter_new( model, NULL );
     g_object_unref( G_OBJECT( model ) );
@@ -221,6 +226,10 @@ GtkWidget* ptk_dir_tree_view_new( PtkFileBrowser* browser,
                        G_CALLBACK ( on_dir_tree_view_drag_motion ),
                        browser );
 
+    g_signal_connect ( ( gpointer ) dir_tree_view, "drag-leave",
+                       G_CALLBACK ( on_dir_tree_view_drag_leave ),
+                       browser );
+
     g_signal_connect ( ( gpointer ) dir_tree_view, "drag-drop",
                        G_CALLBACK ( on_dir_tree_view_drag_drop ),
                        browser );
@@ -382,7 +391,7 @@ void ptk_dir_tree_view_show_hidden_files( GtkTreeView* dir_tree_view,
 {
     GtkTreeModel * filter;
     g_object_set_qdata( G_OBJECT( dir_tree_view ),
-                        dir_tree_view_data, ( gpointer ) show_hidden );
+                        dir_tree_view_data, GINT_TO_POINTER( show_hidden ) );
     filter = gtk_tree_view_get_model( dir_tree_view );
     gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( filter ) );
 }
@@ -456,7 +465,8 @@ gboolean on_dir_tree_view_button_press( GtkWidget* view,
                                 dir_name, sel_files );
                     g_free( dir_name );
                     g_free( file_path );
-                    gtk_menu_popup( GTK_MENU( popup ), NULL, NULL,
+                    if ( popup )
+                        gtk_menu_popup( GTK_MENU( popup ), NULL, NULL,
                                     NULL, NULL, 3, evt->time );
 
                     vfs_file_info_unref( file );
@@ -473,8 +483,8 @@ gboolean on_dir_tree_view_key_press( GtkWidget* view,
                                      gpointer user_data )
 {
     switch(evt->keyval) {
-    case GDK_Left:
-    case GDK_Right:
+    case GDK_KEY_Left:
+    case GDK_KEY_Right:
         break;
     default:
         return FALSE;
@@ -490,17 +500,18 @@ gboolean on_dir_tree_view_key_press( GtkWidget* view,
     GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
 
     switch( evt->keyval ) {
-    case GDK_Left:
+    case GDK_KEY_Left:
         if(gtk_tree_view_row_expanded(GTK_TREE_VIEW(view), path)) {
             gtk_tree_view_collapse_row(GTK_TREE_VIEW(view), path);
         } else if(gtk_tree_path_up(path)) {
             gtk_tree_selection_select_path(select, path);
             gtk_tree_view_set_cursor(GTK_TREE_VIEW(view), path, NULL, FALSE);
         } else {
+            gtk_tree_path_free( path );
             return FALSE;
         }
         break;
-    case GDK_Right:
+    case GDK_KEY_Right:
         if(!gtk_tree_view_row_expanded(GTK_TREE_VIEW(view), path)) {
             gtk_tree_view_expand_row(GTK_TREE_VIEW(view), path, FALSE);
         } else {
@@ -510,22 +521,31 @@ gboolean on_dir_tree_view_key_press( GtkWidget* view,
         }
         break;
     }
+    gtk_tree_path_free( path );
     return TRUE;  
 }
 
 //MOD drag n drop
-static char* dir_tree_view_get_drop_dir( GtkWidget* view, int x, int y )  //MOD added
+static char* dir_tree_view_get_drop_dir( GtkWidget* view, int x, int y )
 {
-    GtkTreePath * tree_path = NULL;
-    GtkTreeModel *model = NULL;
+    GtkTreePath *tree_path = NULL;
+    GtkTreeModel *model;
     GtkTreeIter it;
     VFSFileInfo* file;
     char* dest_path = NULL;
 
-    model = gtk_tree_view_get_model( GTK_TREE_VIEW( view ) );
-    if ( gtk_tree_view_get_path_at_pos( GTK_TREE_VIEW( view ),
-                                        x, y, &tree_path, NULL, NULL, NULL ) )
+    // if drag is in progress, get the dest row path
+    gtk_tree_view_get_drag_dest_row( GTK_TREE_VIEW( view ), &tree_path, NULL );
+    if ( !tree_path )
     {
+        // no drag in progress, get drop path
+        if ( !gtk_tree_view_get_path_at_pos( GTK_TREE_VIEW( view ),
+                                        x, y, &tree_path, NULL, NULL, NULL ) )
+            tree_path = NULL;
+    }
+    if ( tree_path )
+    {
+        model = gtk_tree_view_get_model( GTK_TREE_VIEW( view ) );
         if ( gtk_tree_model_get_iter( model, &it, tree_path ) )
         {
             gtk_tree_model_get( model, &it,
@@ -539,10 +559,15 @@ static char* dir_tree_view_get_drop_dir( GtkWidget* view, int x, int y )  //MOD
         }
         gtk_tree_path_free( tree_path );
     }
+/*  this isn't needed?
     // dest_path is a link? resolve
     if ( dest_path && g_file_test( dest_path, G_FILE_TEST_IS_SYMLINK ) )
-        dest_path = g_file_read_link ( dest_path, NULL );
-            
+    {
+        char* old_dest = dest_path;
+        dest_path = g_file_read_link( old_dest, NULL );
+        g_free( old_dest );
+    }
+*/
     return dest_path;
 }
 
@@ -567,18 +592,57 @@ void on_dir_tree_view_drag_data_received ( GtkWidget *widget,
     /*  Don't call the default handler  */
     g_signal_stop_emission_by_name( widget, "drag-data-received" );
 
-    if ( ( sel_data->length >= 0 ) && ( sel_data->format == 8 ) )
+    if ( ( gtk_selection_data_get_length( sel_data ) >= 0 ) && ( gtk_selection_data_get_format( sel_data ) == 8 ) )
     {
         dest_dir = dir_tree_view_get_drop_dir( widget, x, y );
         if ( dest_dir )
         {
             puri = list = gtk_selection_data_get_uris( sel_data );
+            if( file_browser->pending_drag_status_tree )
+            {
+                // We only want to update drag status, not really want to drop
+                dev_t dest_dev;
+                struct stat statbuf;    // skip stat64
+                if( stat( dest_dir, &statbuf ) == 0 )
+                {
+                    dest_dev = statbuf.st_dev;
+                    if( 0 == file_browser->drag_source_dev_tree )
+                    {
+                        file_browser->drag_source_dev_tree = dest_dev;
+                        for( ; *puri; ++puri )
+                        {
+                            file_path = g_filename_from_uri( *puri, NULL, NULL );
+                            if( stat( file_path, &statbuf ) == 0 && statbuf.st_dev != dest_dev )
+                            {
+                                file_browser->drag_source_dev_tree = statbuf.st_dev;
+                                g_free( file_path );
+                                break;
+                            }
+                            g_free( file_path );
+                        }
+                    }
+                    if( file_browser->drag_source_dev_tree != dest_dev )
+                        // src and dest are on different devices */
+                        gdk_drag_status( drag_context, GDK_ACTION_COPY, time);
+                    else
+                        gdk_drag_status( drag_context, GDK_ACTION_MOVE, time);
+                }
+                else
+                    // stat failed
+                    gdk_drag_status( drag_context, GDK_ACTION_COPY, time);
+
+                g_free( dest_dir );
+                g_strfreev( list );
+                file_browser->pending_drag_status_tree = 0;
+                return;
+            }
+
             if ( puri )
             {
-                if ( 0 == ( drag_context->action &
+                if ( 0 == ( gdk_drag_context_get_selected_action ( drag_context ) &
                             ( GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK ) ) )
                 {
-                    drag_context->action = GDK_ACTION_MOVE;
+                    gdk_drag_status( drag_context, GDK_ACTION_MOVE, time);
                 }
                 gtk_drag_finish ( drag_context, TRUE, FALSE, time );
 
@@ -595,7 +659,7 @@ void on_dir_tree_view_drag_data_received ( GtkWidget *widget,
                 }
                 g_strfreev( list );
 
-                switch ( drag_context->action )
+                switch ( gdk_drag_context_get_selected_action ( drag_context ) )
                 {
                 case GDK_ACTION_COPY:
                     file_action = VFS_FILE_TASK_COPY;
@@ -619,15 +683,23 @@ void on_dir_tree_view_drag_data_received ( GtkWidget *widget,
                                                   GTK_WINDOW( parent_win ),
                                                   file_browser->task_view );
                         ptk_file_task_run( task );
-                        g_free( dest_dir );
                     }
                 }
+                g_free( dest_dir );
                 gtk_drag_finish ( drag_context, TRUE, FALSE, time );
                 return ;
             }
+            g_free( dest_dir );
         }
-        else
-            g_warning ("bad dest_dir in on_dir_tree_view_drag_data_received");
+        //else
+        //    g_warning ("bad dest_dir in on_dir_tree_view_drag_data_received");
+    }
+    /* If we are only getting drag status, not finished. */
+    if( file_browser->pending_drag_status_tree )
+    {
+        gdk_drag_status ( drag_context, GDK_ACTION_COPY, time );
+        file_browser->pending_drag_status_tree = 0;
+        return;
     }
     gtk_drag_finish ( drag_context, FALSE, FALSE, time );
 }
@@ -649,7 +721,6 @@ gboolean on_dir_tree_view_drag_drop ( GtkWidget *widget,
     return TRUE;
 }
 
-
 gboolean on_dir_tree_view_drag_motion ( GtkWidget *widget,
                                       GdkDragContext *drag_context,
                                       gint x,
@@ -658,11 +729,8 @@ gboolean on_dir_tree_view_drag_motion ( GtkWidget *widget,
                                       PtkFileBrowser* file_browser )  //MOD added
 {
     GdkDragAction suggested_action;
-/* this check isn't needed? 
-
     GdkAtom target;
     GtkTargetList* target_list;
-    char* dest_dir = NULL;
 
     target_list = gtk_target_list_new( drag_targets, G_N_ELEMENTS(drag_targets) );
     target = gtk_drag_dest_find_target( widget, drag_context, target_list );
@@ -672,23 +740,69 @@ gboolean on_dir_tree_view_drag_motion ( GtkWidget *widget,
         gdk_drag_status( drag_context, 0, time);
     else
     {
-*/      
         // Need to set suggested_action because default handler assumes copy
         /* Only 'move' is available. The user force move action by pressing Shift key */
-        if( (drag_context->actions & GDK_ACTION_ALL) == GDK_ACTION_MOVE )
+        if( (gdk_drag_context_get_actions ( drag_context ) & GDK_ACTION_ALL) == GDK_ACTION_MOVE )
             suggested_action = GDK_ACTION_MOVE;
         /* Only 'copy' is available. The user force copy action by pressing Ctrl key */
-        else if( (drag_context->actions & GDK_ACTION_ALL) == GDK_ACTION_COPY )
+        else if( (gdk_drag_context_get_actions ( drag_context ) & GDK_ACTION_ALL) == GDK_ACTION_COPY )
             suggested_action = GDK_ACTION_COPY;
         /* Only 'link' is available. The user force link action by pressing Shift+Ctrl key */
-        else if( (drag_context->actions & GDK_ACTION_ALL) == GDK_ACTION_LINK )
+        else if( (gdk_drag_context_get_actions ( drag_context ) & GDK_ACTION_ALL) == GDK_ACTION_LINK )
             suggested_action = GDK_ACTION_LINK;
         /* Several different actions are available. We have to figure out a good default action. */
         else
-            suggested_action = GDK_ACTION_MOVE;
-        drag_context->suggested_action = suggested_action;
-        gdk_drag_status( drag_context, suggested_action, time );
-//    }
+        {
+            int drag_action = xset_get_int( "drag_action", "x" );
+            if ( drag_action == 1 )
+                suggested_action = GDK_ACTION_COPY;
+            else if ( drag_action == 2 )
+                suggested_action = GDK_ACTION_MOVE;
+            else if ( drag_action == 3 )
+                suggested_action = GDK_ACTION_LINK;
+            else
+            {
+                // automatic
+                file_browser->pending_drag_status_tree = 1;
+                gtk_drag_get_data (widget, drag_context, target, time);
+                suggested_action = gdk_drag_context_get_selected_action( drag_context );
+            }
+        }
+#if GTK_CHECK_VERSION (3, 0, 0)
+        /* hack to be able to call the default handler with the correct suggested_action */
+        struct _GdkDragContext {
+          GObject parent_instance;
+
+          /*< private >*/
+          GdkDragProtocol protocol;
+
+          gboolean is_source;
+          GdkWindow *source_window;
+          GdkWindow *dest_window;
+
+          GList *targets;
+          GdkDragAction actions;
+          GdkDragAction suggested_action;
+          GdkDragAction action;
+
+          guint32 start_time;
+
+          GdkDevice *device;
+        };
+        ((struct _GdkDragContext *)drag_context)->suggested_action = suggested_action;
+#else
+        drag_context->suggested_action = suggested_action; // needed for default handler
+#endif
+        gdk_drag_status( drag_context, suggested_action, gtk_get_current_event_time() );
+    }
     return FALSE;
 }
 
+static gboolean on_dir_tree_view_drag_leave ( GtkWidget *widget,
+                                     GdkDragContext *drag_context,
+                                     guint time,
+                                     PtkFileBrowser* file_browser )
+{
+    file_browser->drag_source_dev_tree = 0;
+    return FALSE;
+}
