@@ -19,6 +19,8 @@
 #include "vfs-mime-type.h"
 #include "settings.h"
 
+#include "gtk2-compat.h"
+
 typedef struct _ArchiveHandler
 {
     const char* mime_type;
@@ -35,49 +37,49 @@ const ArchiveHandler handlers[]=
     {
         {
             "application/x-bzip-compressed-tar",
-            "tar %o -cjf",
-            "tar -xjf",
+            "tar %o -cvjf",
+            "tar -xvjf",
             "tar -tvf",
             ".tar.bz2", "arc_tar_bz2", TRUE
         },
         {
             "application/x-compressed-tar",
-            "tar %o -czf",
-            "tar -xzf",
+            "tar %o -cvzf",
+            "tar -xvzf",
             "tar -tvf",
             ".tar.gz", "arc_tar_gz", TRUE
         },
         {
             "application/x-xz-compressed-tar",  //MOD added
-            "tar %o -cJf",
-            "tar -xJf",
+            "tar %o -cvJf",
+            "tar -xvJf",
             "tar -tvf",
             ".tar.xz", "arc_tar_xz", TRUE
         },
         {
             "application/zip",
             "zip %o -r",
-            "unzip -qq",
+            "unzip",
             "unzip -l",
             ".zip", "arc_zip", TRUE
         },
         {
             "application/x-7z-compressed",
-            "7za %o a",
+            "7za %o a", // hack - also uses 7zr if available
             "7za x",
             "7za l",
             ".7z", "arc_7z", TRUE
         },
         {
             "application/x-tar",
-            "tar %o -cf",
-            "tar -xf",
+            "tar %o -cvf",
+            "tar -xvf",
             "tar -tvf",
             ".tar", "arc_tar", TRUE
         },
         {
             "application/x-rar",
-            NULL,
+            "rar a -r %o",
             "unrar -o- x",
             "unrar lt",
             ".rar", "arc_rar", TRUE
@@ -95,7 +97,7 @@ const ArchiveHandler handlers[]=
 static void on_format_changed( GtkComboBox* combo, gpointer user_data )
 {
     GtkFileChooser* dlg = GTK_FILE_CHOOSER(user_data);
-/*
+
     int i, n, len;
     char* ext = NULL;
     char *path, *name, *new_name;
@@ -103,7 +105,7 @@ static void on_format_changed( GtkComboBox* combo, gpointer user_data )
     path = gtk_file_chooser_get_filename( dlg );
     if( !path )
         return;
-    ext = gtk_combo_box_get_active_text(combo);
+    ext = gtk_combo_box_text_get_active_text( GTK_COMBO_BOX_TEXT( combo ) );
     name = g_path_get_basename( path );
     g_free( path );
     n = gtk_tree_model_iter_n_children( gtk_combo_box_get_model(combo),
@@ -123,23 +125,26 @@ static void on_format_changed( GtkComboBox* combo, gpointer user_data )
     g_free( ext );
     gtk_file_chooser_set_current_name( dlg, new_name );
     g_free( new_name );
-*/
+
     // set options
-    int i = gtk_combo_box_get_active(combo);
+    i = gtk_combo_box_get_active(combo);
     GtkEntry* entry = (GtkEntry*)g_object_get_data( G_OBJECT(dlg), "entry" );
     if ( xset_get_s( handlers[i].name ) )
         gtk_entry_set_text( entry, xset_get_s( handlers[i].name ) );
     else
         gtk_entry_buffer_delete_text( gtk_entry_get_buffer( entry ), 0, -1 );
 }
-
-void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char* cwd )
+                                                        
+void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files,
+                                                                const char* cwd )
 {
     GList* l;
     GtkWidget* dlg;
     GtkFileFilter* filter;
     char* dest_file;
     char* ext;
+    char* str;
+    char* cmd;
     int res;
     //char **argv, **cmdv;
     int argc, cmdc, i, n;
@@ -150,7 +155,8 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     char* desc;
 
     dlg = gtk_file_chooser_dialog_new( _("Save Archive"),
-                                       gtk_widget_get_toplevel( file_browser ),
+                                       GTK_WINDOW( gtk_widget_get_toplevel(
+                                             GTK_WIDGET( file_browser ) ) ),
                                        GTK_FILE_CHOOSER_ACTION_SAVE,
                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                        GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL );
@@ -158,20 +164,21 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     hbox = gtk_hbox_new( FALSE, 4 );
     gtk_box_pack_start( GTK_BOX(hbox),
                         gtk_label_new( _("Archive Format:") ),
-                        FALSE, FALSE, 2 );
+                        FALSE, TRUE, 2 );
 
-    combo = gtk_combo_box_new_text();
+    combo = gtk_combo_box_text_new();
 
     for( i = 0; i < G_N_ELEMENTS(handlers); ++i )
     {
         if( handlers[i].compress_cmd )
         {
             gtk_file_filter_add_mime_type( filter, handlers[i].mime_type );
-            gtk_combo_box_append_text( GTK_COMBO_BOX(combo), handlers[i].file_ext );
+            gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(combo), handlers[i].file_ext );
         }
     }
     gtk_file_chooser_set_filter( GTK_FILE_CHOOSER(dlg), filter );
-    n = gtk_tree_model_iter_n_children( gtk_combo_box_get_model(combo), NULL );
+    n = gtk_tree_model_iter_n_children( gtk_combo_box_get_model( 
+                                                    GTK_COMBO_BOX( combo ) ), NULL );
     i = xset_get_int( "arc_dlg", "z" );
     if ( i < 0 || i > n - 1 )
         i = 0;
@@ -180,36 +187,41 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     gtk_box_pack_start( GTK_BOX(hbox),
                         combo,
                         FALSE, FALSE, 2 );
-    gtk_box_pack_start( GTK_BOX(hbox),
-                        gtk_vseparator_new(),
-                        FALSE, FALSE, 2 );
     gtk_box_pack_start( GTK_BOX(hbox),
                         gtk_label_new( _("Options:") ),
                         FALSE, FALSE, 2 );
+
     GtkEntry* entry = ( GtkEntry* ) gtk_entry_new();
     if ( xset_get_s( handlers[i].name ) )
         gtk_entry_set_text( entry, xset_get_s( handlers[i].name ) );
-    //gtk_entry_set_width_chars( entry, 30 );
-    GtkWidget* align = gtk_alignment_new( 0, 0, .5, 1 );
-    gtk_alignment_set_padding( align, 0, 0, 0, 0 );
-    gtk_container_add ( GTK_CONTAINER ( align ), entry );
-    gtk_box_pack_start( GTK_BOX(hbox), align, TRUE, TRUE, 4 );
+    //GtkWidget* align = gtk_alignment_new( 0, 0, 1, 1 );
+    //gtk_alignment_set_padding( GTK_ALIGNMENT( align ), 0, 0, 0, 0 );
+    //gtk_container_add ( GTK_CONTAINER ( align ), GTK_WIDGET( entry ) );
+    gtk_box_pack_start( GTK_BOX(hbox), GTK_WIDGET( entry ), TRUE, TRUE, 4 );
     g_object_set_data( G_OBJECT( dlg ), "entry", entry );
 
     gtk_widget_show_all( hbox );
-    gtk_file_chooser_set_extra_widget( GTK_FILE_CHOOSER(dlg), hbox );
+    gtk_box_pack_start( GTK_BOX( gtk_dialog_get_content_area ( 
+                                        GTK_DIALOG( dlg ) ) ),
+                                        hbox, FALSE, TRUE, 0 );
 
     gtk_file_chooser_set_action( GTK_FILE_CHOOSER(dlg), GTK_FILE_CHOOSER_ACTION_SAVE );
-//#if GTK_CHECK_VERSION(2, 8, 0)
-//    gtk_file_chooser_set_do_overwrite_confirmation( GTK_FILE_CHOOSER(dlg), TRUE );
-//#endif
+    gtk_file_chooser_set_do_overwrite_confirmation( GTK_FILE_CHOOSER(dlg), TRUE );
+
     if( files )
     {
-        gtk_file_chooser_set_current_name( GTK_FILE_CHOOSER(dlg),
-                    vfs_file_info_get_disp_name( (VFSFileInfo*)files->data ) );
+//        gtk_file_chooser_set_current_name( GTK_FILE_CHOOSER(dlg),
+//                    vfs_file_info_get_disp_name( (VFSFileInfo*)files->data ) );
+
+
+        ext = gtk_combo_box_text_get_active_text( GTK_COMBO_BOX_TEXT(combo) );
+        dest_file = g_strjoin( NULL, 
+                        vfs_file_info_get_disp_name( (VFSFileInfo*)files->data ),
+                        ext, NULL );
+        gtk_file_chooser_set_current_name( GTK_FILE_CHOOSER(dlg), dest_file );
+        g_free( dest_file );
 
 /*
-        ext = gtk_combo_box_get_active_text( GTK_COMBO_BOX(combo) );
         if ( !files->next )
         {
             dest_file = g_build_filename( cwd,
@@ -232,8 +244,9 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
         }
         else
             gtk_file_chooser_set_current_name( GTK_FILE_CHOOSER(dlg), "new archive" );
-        g_free( ext );
 */
+        g_free( ext );
+
     }
     gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER (dlg), cwd );
     
@@ -259,8 +272,10 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     if ( res == GTK_RESPONSE_OK )
     {
         char* str;
-        width = GTK_WIDGET( dlg ) ->allocation.width;
-        height = GTK_WIDGET( dlg ) ->allocation.height;
+        GtkAllocation allocation;
+        gtk_widget_get_allocation ( GTK_WIDGET ( dlg ), &allocation );
+        width = allocation.width;
+        height = allocation.height;
         if ( width && height )
         {
             str = g_strdup_printf( "%d", width );
@@ -292,22 +307,43 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     }
     else
         s1 = g_strdup( handlers[format].compress_cmd );
+        
+    if ( format == 4 )
+    {
+        // for 7z use 7za OR 7zr
+        str = g_find_program_in_path( "7za" );
+        if ( !str )
+            str = g_find_program_in_path( "7zr" );
+        if ( str )
+        {
+            cmd = s1;
+            s1 = replace_string( cmd, "7za", str, FALSE );
+            g_free( cmd );
+            g_free( str );
+        }
+    }
+
     udest_file = g_filename_display_name( dest_file );
+/*
     if ( !g_str_has_suffix( udest_file, handlers[format].file_ext ) )
     {
         g_free( dest_file );
         dest_file = udest_file;
         udest_file = g_strdup_printf( "%s%s", dest_file, handlers[format].file_ext );
     }
+*/
     g_free( dest_file );
     
     // overwrite?
+/*
     if ( g_file_test( udest_file, G_FILE_TEST_EXISTS ) )
     {
         char* afile = g_path_get_basename( udest_file );
         char* msg = g_strdup_printf( _("Archive '%s' exists.\n\nOverwrite?"), afile );
         g_free( afile );
-        if ( xset_msg_dialog( file_browser, GTK_MESSAGE_QUESTION, _("Overwrite?"), NULL, GTK_BUTTONS_OK_CANCEL, msg, NULL ) != GTK_RESPONSE_OK )
+        if ( xset_msg_dialog( GTK_WIDGET( file_browser ), GTK_MESSAGE_QUESTION,
+                                        _("Overwrite?"), NULL, GTK_BUTTONS_OK_CANCEL,
+                                        msg, NULL, NULL ) != GTK_RESPONSE_OK )
         {
             g_free( udest_file );
             g_free( s1 );
@@ -316,10 +352,10 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
         }
         g_free( msg );
     }
-    
+*/    
     char* udest_quote = bash_quote( udest_file );
     //char* cmd = g_strdup_printf( "%s %s \"${fm_filenames[@]}\"", s1, udest_quote );
-    char* cmd = g_strdup_printf( "%s %s", s1, udest_quote );
+    cmd = g_strdup_printf( "%s %s", s1, udest_quote );
     g_free( udest_file );
     g_free( udest_quote );
     g_free( s1 );
@@ -337,12 +373,24 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
     
     // task
     char* task_name = g_strdup_printf( _("Archive") );
-    PtkFileTask* task = ptk_file_exec_new( task_name, cwd,
-                                        file_browser, file_browser->task_view );
+    PtkFileTask* task = ptk_file_exec_new( task_name, cwd, GTK_WIDGET( file_browser ),
+                                                        file_browser->task_view );
     g_free( task_name );
-    task->task->exec_command = cmd;
     task->task->exec_browser = file_browser;
-    task->task->exec_sync = TRUE;
+    if ( format == 3 || format == 4 || format == 6 )
+    {
+        // use terminal for noisy rar, 7z, zip creation
+        task->task->exec_terminal = TRUE;
+        task->task->exec_sync = FALSE;
+        s1 = cmd;
+        cmd = g_strdup_printf( "%s ; fm_err=$?; if [ $fm_err -ne 0 ]; then echo; echo -n '%s: '; read s; exit $fm_err; fi", s1, "[ Finished With Errors ]  Press Enter to close" );
+        g_free( s1 );
+    }
+    else
+    {
+        task->task->exec_sync = TRUE;
+    }
+    task->task->exec_command = cmd;
     task->task->exec_show_error = TRUE;
     task->task->exec_export = TRUE;
     //task->task->exec_keep_tmp = TRUE;
@@ -388,9 +436,10 @@ void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char*
 }
 
 void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
-                                                                char* dest_dir )
+                                            const char* cwd, const char* dest_dir )
 {
     GtkWidget* dlg;
+    GtkWidget* dlgparent = NULL;
     char* choose_dir = NULL;
     gboolean create_parent;
     gboolean write_access;
@@ -401,22 +450,32 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
     GList* l;
     char* mkparent;
     char* perm;
+    char* prompt;
     char* full_path;
     char* full_quote;
     char* dest_quote;
-    char* dest;
+    const char* dest;
     char* cmd;
     char* str;
     int i, n, j;
+    struct stat64 statbuf;
+    gboolean keep_term;
+    gboolean in_term;    
     const char* suffix[] = { ".tar", ".tar.gz", ".tgz", ".tar.bz2", ".tar.xz",
                                             ".txz", ".zip", ".rar", ".7z" };
 
     if( !files )
         return;
+        
+    if ( file_browser )
+        dlgparent = gtk_widget_get_toplevel( GTK_WIDGET( file_browser ) );
+    //else if ( desktop )
+    //    dlgparent = gtk_widget_get_toplevel( desktop );  // causes drag action???
+        
     if( !dest_dir )
     {
         dlg = gtk_file_chooser_dialog_new( _("Extract To"),
-                                           gtk_widget_get_toplevel( file_browser ),
+                                           GTK_WINDOW( dlgparent ),
                                            GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
                                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                            GTK_STOCK_OK, GTK_RESPONSE_OK, NULL );
@@ -424,10 +483,11 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
         GtkWidget* hbox = gtk_hbox_new( FALSE, 10 );
         GtkWidget* chk_parent = gtk_check_button_new_with_mnemonic(
                                                     _("Cre_ate subfolder(s)") );
-        gtk_toggle_button_set_active( chk_parent, xset_get_b( "arc_dlg" ) );
+        gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( chk_parent ),
+                                                    xset_get_b( "arc_dlg" ) );
         GtkWidget* chk_write = gtk_check_button_new_with_mnemonic(
                                                     _("Make contents user-_writable") );
-        gtk_toggle_button_set_active( chk_write,
+        gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( chk_write ),
                                 xset_get_int( "arc_dlg", "s" ) == 1 && geteuid() != 0 );
         gtk_widget_set_sensitive( chk_write, geteuid() != 0 );
         gtk_box_pack_start( GTK_BOX(hbox), chk_parent, FALSE, FALSE, 6 );
@@ -435,8 +495,7 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
         gtk_widget_show_all( hbox );
         gtk_file_chooser_set_extra_widget( GTK_FILE_CHOOSER(dlg), hbox );
 
-        gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER (dlg),
-                                    ptk_file_browser_get_cwd( file_browser ) );
+        gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER (dlg), cwd );
 
         int width = xset_get_int( "arc_dlg", "x" );
         int height = xset_get_int( "arc_dlg", "y" );
@@ -453,8 +512,10 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
 
         if( gtk_dialog_run( GTK_DIALOG(dlg) ) == GTK_RESPONSE_OK )
         {
-            width = GTK_WIDGET( dlg ) ->allocation.width;
-            height = GTK_WIDGET( dlg ) ->allocation.height;
+            GtkAllocation allocation;
+            gtk_widget_get_allocation ( GTK_WIDGET ( dlg ), &allocation );
+            width = allocation.width;
+            height = allocation.height;
             if ( width && height )
             {
                 str = g_strdup_printf( "%d", width );
@@ -465,8 +526,8 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
                 g_free( str );
             }
             choose_dir = gtk_file_chooser_get_filename( GTK_FILE_CHOOSER(dlg) );
-            create_parent = gtk_toggle_button_get_active( chk_parent );
-            write_access = gtk_toggle_button_get_active( chk_write );
+            create_parent = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( chk_parent ) );
+            write_access = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( chk_write ) );
             xset_set_b( "arc_dlg", create_parent );
             str = g_strdup_printf( "%d", write_access ? 1 : 0 );
             xset_set( "arc_dlg", "s", str );
@@ -502,14 +563,37 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
             continue;
     
         // handler found
-        full_path = g_build_filename( ptk_file_browser_get_cwd( file_browser ),
-                                        vfs_file_info_get_name( file ), NULL );
+        keep_term = TRUE;
+        in_term = FALSE;
+        full_path = g_build_filename( cwd, vfs_file_info_get_name( file ), NULL );
         full_quote = bash_quote( full_path );
         dest_quote = bash_quote( dest );
         if ( list_contents )
         {
             // list contents
             cmd = g_strdup_printf( "%s %s | more -d", handlers[i].list_cmd, full_quote );
+            in_term = TRUE;
+        }
+        else if ( !strcmp( type, "application/x-gzip" ) )
+        {
+            // extract .gz
+            char* base = g_build_filename( dest, vfs_file_info_get_name( file ),
+                                                                        NULL );
+            if ( g_str_has_suffix( base, ".gz" ) )
+                base[strlen(base)-3] = '\0';
+            char* test_path = g_strdup( base );
+            n = 1;
+            while ( lstat64( test_path, &statbuf ) == 0 )
+            {
+                g_free( test_path );
+                test_path = g_strdup_printf( "%s-%s%d", base, _("copy"), ++n );
+            }
+            g_free( dest_quote );
+            dest_quote = bash_quote( test_path );
+            g_free( test_path );
+            g_free( base );
+            cmd = g_strdup_printf( "%s -c %s > %s", handlers[i].extract_cmd,
+                                                    full_quote, dest_quote );
         }
         else
         {
@@ -537,10 +621,11 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
                 char* parent_path = g_build_filename( dest, parent_name, NULL );
                 char* parent_orig = g_strdup( parent_path );
                 n = 1;
-                while ( g_file_test( parent_path, G_FILE_TEST_EXISTS ) )
+                while ( lstat64( parent_path, &statbuf ) == 0 )
                 {
                     g_free( parent_path );
-                    parent_path = g_strdup_printf( "%s-copy%d", parent_orig, ++n );
+                    parent_path = g_strdup_printf( "%s-%s%d", parent_orig,
+                                                                _("copy"), ++n );
                 }
                 g_free( parent_orig );
 
@@ -550,43 +635,69 @@ void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
                 if ( write_access && geteuid() != 0 )
                     perm = g_strdup_printf( " && chmod -R u+rwX %s", parent_quote );
                 else
-                    perm = g_strdup_printf( "" );
+                    perm = g_strdup( "" );
                 g_free( parent_path );
                 g_free( parent_quote );
             }
             else
             {
                 // no create parent
-                mkparent = g_strdup_printf( "" );
+                mkparent = g_strdup( "" );
                 if ( write_access && geteuid() != 0 && strcmp( type, "application/x-gzip" ) )
                     perm = g_strdup_printf( " && chmod -R u+rwX %s/*", dest_quote );
                 else
-                    perm = g_strdup_printf( "" );
+                    perm = g_strdup( "" );
             }
             
-            cmd = g_strdup_printf( "cd %s && %s%s %s%s", dest_quote, mkparent,
-                                handlers[i].extract_cmd, full_quote, perm );
+            if ( i == 3 || i == 4 || i == 6 )
+            {
+                // zip 7z rar in terminal for password & output
+                in_term = TRUE;  // run in terminal
+                keep_term = FALSE;
+                prompt = g_strdup_printf( " ; fm_err=$?; if [ $fm_err -ne 0 ]; then echo; echo -n '%s: '; read s; exit $fm_err; fi", /* no translate for security*/
+                            "[ Finished With Errors ]  Press Enter to close" );
+            }
+            else
+                prompt = g_strdup( "" );
+            
+            char* handler = NULL;
+            if ( i == 4 )
+            {
+                // for 7z use 7za OR 7zr
+                str = g_find_program_in_path( "7za" );
+                if ( !str )
+                    str = g_find_program_in_path( "7zr" );
+                if ( str )
+                {
+                    handler = replace_string( handlers[i].extract_cmd, "7za", str, FALSE );
+                    g_free( str );
+                }
+            }
+            cmd = g_strdup_printf( "cd %s && %s%s %s%s%s", dest_quote, mkparent,
+                                handler ? handler : handlers[i].extract_cmd,
+                                full_quote, prompt, perm );
             g_free( mkparent );
             g_free( perm );
-            if ( i == 4 )  //application/x-7z-compressed
-                list_contents = TRUE;  // run in terminal
+            g_free( prompt );
+            g_free( handler );
         }
         g_free( dest_quote );
         g_free( full_quote );
         g_free( full_path );
 
         // task
-        char* task_name = g_strdup_printf( _("Extract %s"), vfs_file_info_get_name( file ) );
-        PtkFileTask* task = ptk_file_exec_new( task_name, ptk_file_browser_get_cwd( file_browser ),
-                                            file_browser, file_browser->task_view );
+        char* task_name = g_strdup_printf( _("Extract %s"),
+                                                vfs_file_info_get_name( file ) );
+        PtkFileTask* task = ptk_file_exec_new( task_name, cwd, dlgparent,
+                                file_browser ? file_browser->task_view : NULL );
         g_free( task_name );
         task->task->exec_command = cmd;
         task->task->exec_browser = file_browser;
-        task->task->exec_sync = !list_contents;
+        task->task->exec_sync = !in_term;
         task->task->exec_show_error = TRUE;
-        task->task->exec_show_output = list_contents;
-        task->task->exec_terminal = list_contents;
-        task->task->exec_keep_terminal = TRUE;
+        task->task->exec_show_output = in_term;
+        task->task->exec_terminal = in_term;
+        task->task->exec_keep_terminal = keep_term;
         task->task->exec_export = FALSE;
     //task->task->exec_keep_tmp = TRUE;
         XSet* set = xset_get( "arc_extract" );
