@@ -21,12 +21,12 @@
 
 G_BEGIN_DECLS
 
-void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files, char* cwd );
-
+void ptk_file_archiver_create( PtkFileBrowser* file_browser, GList* files,
+											const char* cwd );
 void ptk_file_archiver_extract( PtkFileBrowser* file_browser, GList* files,
-                                                                char* dest_dir );
+                                            const char* cwd, const char* dest_dir );
 gboolean ptk_file_archiver_is_format_supported( VFSMimeType* mime,
-                                                gboolean extract );
+                                            gboolean extract );
 
 G_END_DECLS
 #endif
