@@ -54,7 +54,8 @@ void on_bookmark_open_tab( GtkMenuItem* item, PtkFileBrowser* file_browser );
 
 void mount_network( PtkFileBrowser* file_browser, const char* url, gboolean new_tab );
 void mount_iso( PtkFileBrowser* file_browser, const char* path );
-void ptk_location_view_dev_menu( GtkWidget* parent, GtkWidget* menu );
+void ptk_location_view_dev_menu( GtkWidget* parent, PtkFileBrowser* file_browser, 
+                                                            GtkWidget* menu );
 
 G_END_DECLS
 
