@@ -20,10 +20,8 @@ G_BEGIN_DECLS
 
 typedef struct
 {
-    GList* history;
-    GList* current;
-    char* editing;
     PtkFileBrowser* browser;
+    guint seek_timer;
 } EntryData;
 
 GtkWidget* ptk_path_entry_new( PtkFileBrowser* file_browser );
