@@ -25,7 +25,7 @@
 
 static int big_thumb_size = 48, small_thumb_size = 20;
 static gboolean utf8_file_name = FALSE;
-static char* desktop_dir = NULL;   //MOD added
+static const char* desktop_dir = NULL;   //MOD added
 
 void vfs_file_info_set_utf8_filename( gboolean is_utf8 )
 {
@@ -51,6 +51,16 @@ static void vfs_file_info_clear( VFSFileInfo* fi )
         g_free( fi->name );
         fi->name = NULL;
     }
+    if ( fi->collate_key )  //sfm
+    {
+        g_free( fi->collate_key );
+        fi->collate_key = NULL;
+    }    
+    if ( fi->collate_icase_key )  //sfm
+    {
+        g_free( fi->collate_icase_key );
+        fi->collate_icase_key = NULL;
+    }    
     if ( fi->disp_size )
     {
         g_free( fi->disp_size );
@@ -68,12 +78,12 @@ static void vfs_file_info_clear( VFSFileInfo* fi )
     }
     if ( fi->big_thumbnail )
     {
-        gdk_pixbuf_unref( fi->big_thumbnail );
+        g_object_unref( fi->big_thumbnail );
         fi->big_thumbnail = NULL;
     }
     if ( fi->small_thumbnail )
     {
-        gdk_pixbuf_unref( fi->small_thumbnail );
+        g_object_unref( fi->small_thumbnail );
         fi->small_thumbnail = NULL;
     }
 
@@ -106,7 +116,7 @@ gboolean vfs_file_info_get( VFSFileInfo* fi,
                             const char* file_path,
                             const char* base_name )
 {
-    struct stat file_stat;
+    struct stat64 file_stat;
     vfs_file_info_clear( fi );
 
     if ( base_name )
@@ -114,7 +124,7 @@ gboolean vfs_file_info_get( VFSFileInfo* fi,
     else
         fi->name = g_path_get_basename( file_path );
 
-    if ( lstat( file_path, &file_stat ) == 0 )
+    if ( lstat64( file_path, &file_stat ) == 0 )
     {
         /* This is time-consuming but can save much memory */
         fi->mode = file_stat.st_mode;
@@ -122,6 +132,7 @@ gboolean vfs_file_info_get( VFSFileInfo* fi,
         fi->uid = file_stat.st_uid;
         fi->gid = file_stat.st_gid;
         fi->size = file_stat.st_size;
+//printf("size %s %llu\n", fi->name, fi->size );
         fi->mtime = file_stat.st_mtime;
         fi->atime = file_stat.st_atime;
         fi->blksize = file_stat.st_blksize;
@@ -138,6 +149,11 @@ gboolean vfs_file_info_get( VFSFileInfo* fi,
         fi->mime_type = vfs_mime_type_get_from_file( file_path,
                                                      fi->disp_name,
                                                      &file_stat );
+        //sfm get collate keys
+        fi->collate_key = g_utf8_collate_key_for_filename( fi->disp_name, -1 );
+        char* str = g_utf8_casefold( fi->disp_name, -1 );
+        fi->collate_icase_key = g_utf8_collate_key_for_filename( str, -1 );
+        g_free( str );
         return TRUE;
     }
     else
@@ -161,6 +177,13 @@ void vfs_file_info_set_disp_name( VFSFileInfo* fi, const char* name )
     if ( fi->disp_name && fi->disp_name != fi->name )
         g_free( fi->disp_name );
     fi->disp_name = g_strdup( name );
+    //sfm get new collate keys
+    g_free( fi->collate_key );
+    g_free( fi->collate_icase_key );
+    fi->collate_key = g_utf8_collate_key_for_filename( fi->disp_name, -1 );
+    char* str = g_utf8_casefold( fi->disp_name, -1 );
+    fi->collate_icase_key = g_utf8_collate_key_for_filename( str, -1 );
+    g_free( str );
 }
 
 void vfs_file_info_set_name( VFSFileInfo* fi, const char* name )
@@ -200,7 +223,7 @@ void vfs_file_info_reload_mime_type( VFSFileInfo* fi,
                                      const char* full_path )
 {
     VFSMimeType * old_mime_type;
-    struct stat file_stat;
+    struct stat64 file_stat;
 
     /* convert VFSFileInfo to struct stat */
     /* In current implementation, only st_mode is used in
@@ -255,7 +278,7 @@ GdkPixbuf* vfs_file_info_get_big_icon( VFSFileInfo* fi )
             {
                 icon_name = ( char* ) g_object_steal_data(
                                 G_OBJECT(fi->big_thumbnail), "name" );
-                gdk_pixbuf_unref( fi->big_thumbnail );
+                g_object_unref( fi->big_thumbnail );
                 fi->big_thumbnail = NULL;
             }
             if ( G_LIKELY( icon_name ) )
@@ -272,7 +295,7 @@ GdkPixbuf* vfs_file_info_get_big_icon( VFSFileInfo* fi )
             else
                 g_free( icon_name );
         }
-        return fi->big_thumbnail ? gdk_pixbuf_ref( fi->big_thumbnail ) : NULL;
+        return fi->big_thumbnail ? g_object_ref( fi->big_thumbnail ) : NULL;
     }
     if( G_UNLIKELY(!fi->mime_type) )
         return NULL;
@@ -282,19 +305,21 @@ GdkPixbuf* vfs_file_info_get_big_icon( VFSFileInfo* fi )
 GdkPixbuf* vfs_file_info_get_small_icon( VFSFileInfo* fi )
 {
     if ( fi->flags & VFS_FILE_INFO_DESKTOP_ENTRY && fi->small_thumbnail )  //sfm
-        return gdk_pixbuf_ref( fi->small_thumbnail );
-    
+        return g_object_ref( fi->small_thumbnail );
+
+    if( G_UNLIKELY(!fi->mime_type) )
+        return NULL;
     return vfs_mime_type_get_icon( fi->mime_type, FALSE );
 }
 
 GdkPixbuf* vfs_file_info_get_big_thumbnail( VFSFileInfo* fi )
 {
-    return fi->big_thumbnail ? gdk_pixbuf_ref( fi->big_thumbnail ) : NULL;
+    return fi->big_thumbnail ? g_object_ref( fi->big_thumbnail ) : NULL;
 }
 
 GdkPixbuf* vfs_file_info_get_small_thumbnail( VFSFileInfo* fi )
 {
-    return fi->small_thumbnail ? gdk_pixbuf_ref( fi->small_thumbnail ) : NULL;
+    return fi->small_thumbnail ? g_object_ref( fi->small_thumbnail ) : NULL;
 }
 
 const char* vfs_file_info_get_disp_owner( VFSFileInfo* fi )
@@ -356,18 +381,49 @@ time_t* vfs_file_info_get_atime( VFSFileInfo* fi )
 
 static void get_file_perm_string( char* perm, mode_t mode )
 {
-    perm[ 0 ] = S_ISDIR( mode ) ? 'd' : ( S_ISLNK( mode ) ? 'l' : '-' );
+    if ( S_ISREG( mode ) ) //sfm
+        perm[0] = '-';
+    else if ( S_ISDIR( mode ) )
+        perm[0] = 'd';
+    else if ( S_ISLNK( mode ) )
+        perm[0] = 'l';
+    else if ( G_UNLIKELY( S_ISCHR( mode ) ) )
+        perm[0] = 'c';
+    else if ( G_UNLIKELY( S_ISBLK( mode ) ) )
+        perm[0] = 'b';
+    else if ( G_UNLIKELY( S_ISFIFO( mode ) ) )
+        perm[0] = 'p';
+    else if ( G_UNLIKELY( S_ISSOCK( mode ) ) )
+        perm[0] = 's';
+    else
+        perm[0] = '-';
     perm[ 1 ] = ( mode & S_IRUSR ) ? 'r' : '-';
     perm[ 2 ] = ( mode & S_IWUSR ) ? 'w' : '-';
-    perm[ 3 ] = ( mode & S_IXUSR ) ? 'x' : '-';
+    if ( G_UNLIKELY( mode & S_ISUID ) ) //sfm
+    {
+        if ( G_LIKELY( mode & S_IXUSR ) )
+            perm[ 3 ] = 's';
+        else
+            perm[ 3 ] = 'S';        
+    }
+    else
+        perm[ 3 ] = ( mode & S_IXUSR ) ? 'x' : '-';
     perm[ 4 ] = ( mode & S_IRGRP ) ? 'r' : '-';
     perm[ 5 ] = ( mode & S_IWGRP ) ? 'w' : '-';
-    perm[ 6 ] = ( mode & S_IXGRP ) ? 'x' : '-';
+    if ( G_UNLIKELY( mode & S_ISGID ) ) //sfm
+    {
+        if ( G_LIKELY( mode & S_IXGRP ) )
+            perm[ 6 ] = 's';
+        else
+            perm[ 6 ] = 'S';        
+    }
+    else
+        perm[ 6 ] = ( mode & S_IXGRP ) ? 'x' : '-';
     perm[ 7 ] = ( mode & S_IROTH ) ? 'r' : '-';
     perm[ 8 ] = ( mode & S_IWOTH ) ? 'w' : '-';
-    if ( mode & S_ISVTX ) //MOD
+    if ( G_UNLIKELY( mode & S_ISVTX ) ) //MOD
     {
-        if ( mode & S_IXOTH )
+        if ( G_LIKELY( mode & S_IXOTH ) )
             perm[ 9 ] = 't';
         else
             perm[ 9 ] = 'T';        
@@ -386,9 +442,8 @@ const char* vfs_file_info_get_disp_perm( VFSFileInfo* fi )
 }
 
 void vfs_file_size_to_string_format( char* buf, guint64 size, char* format ) //MOD added
-{
+{   // if format == NULL uses automatic format based on size
     char * unit;
-    /* guint point; */
     gfloat val;
 
     /*
@@ -407,12 +462,12 @@ void vfs_file_size_to_string_format( char* buf, guint64 size, char* format ) //M
 	        if (app_settings.use_si_prefix==TRUE)
 	        {
 	            val = ((gfloat)size) / (( guint64 ) 1000000000000 );
-	            unit = "T";
+	            unit = _("T");
             }
             else
             {
                 val = ((gfloat)size) / ( ( guint64 ) 1 << 40 );
-                unit = "T";  //MOD was TiB
+                unit = _("T");  //MOD was TiB
             }
         }
         else
@@ -425,12 +480,12 @@ void vfs_file_size_to_string_format( char* buf, guint64 size, char* format ) //M
 	        if (app_settings.use_si_prefix==TRUE)
 	        {
 	            val = ((gfloat)size) / (( guint64 ) 1000000000 );
-	            unit = "G";
+	            unit = _("G");
             }
             else
             {
                 val = ((gfloat)size) / ( ( guint64 ) 1 << 30 );
-                unit = "G";  //MOD was GiB
+                unit = _("G");  //MOD was GiB
             }
         }
     }
@@ -444,12 +499,12 @@ void vfs_file_size_to_string_format( char* buf, guint64 size, char* format ) //M
 	    if (app_settings.use_si_prefix==TRUE)
 	    {
 	        val = ((gfloat)size) / (( guint64 ) 1000000 );
-	        unit = "M";
+	        unit = _("M");
         }
         else
         {
             val = ((gfloat)size) / ( ( guint64 ) 1 << 20 );
-            unit = "M";  //MOD was MiB
+            unit = _("M");  //MOD was MiB
         }
     }
     else if ( size > ( 1 << 10 ) )
@@ -462,22 +517,26 @@ void vfs_file_size_to_string_format( char* buf, guint64 size, char* format ) //M
 	    if (app_settings.use_si_prefix==TRUE)
 	    {
 	        val = ((gfloat)size) / (( guint64 ) 1000 );
-	        unit = "K";  //MOD was KB
+	        unit = _("K");  //MOD was KB
 	    }
 	    else
 	    {
 	        val = ((gfloat)size) / ( ( guint64 ) 1 << 10 );
-            unit = "K";  //MOD was KiB
+            unit = _("K");  //MOD was KiB
 	    }
     }
     else
     {
-        unit = size > 1 ? "B" : "B";
-        sprintf( buf, "%u%s", ( guint ) size, unit );
+        unit = _("B"); //size > 1 ? _("B") : _("B");
+        sprintf( buf, "%u %s", ( guint ) size, unit );
         return ;
     }
-    /* sprintf( buf, "%llu.%u %s", size, point, unit ); */
-    sprintf( buf, format ? format : "%.0f%s", val, unit );
+    if ( format )
+        sprintf( buf, format, val, unit );  // "%.0f%s"
+    else if ( val < 10 )
+        sprintf( buf, "%.1f %s", val, unit );
+    else
+        sprintf( buf, "%.0f %s", val, unit );
 }
 
 void vfs_file_size_to_string( char* buf, guint64 size )
@@ -502,12 +561,12 @@ void vfs_file_size_to_string( char* buf, guint64 size )
 	        if (app_settings.use_si_prefix==TRUE)
 	        {
 	            val = ((gfloat)size) / (( guint64 ) 1000000000000 );
-	            unit = "T";
+	            unit = _("T");
             }
             else
             {
                 val = ((gfloat)size) / ( ( guint64 ) 1 << 40 );
-                unit = "T";  //MOD was TiB
+                unit = _("T");  //MOD was TiB
             }
         }
         else
@@ -520,12 +579,12 @@ void vfs_file_size_to_string( char* buf, guint64 size )
 	        if (app_settings.use_si_prefix==TRUE)
 	        {
 	            val = ((gfloat)size) / (( guint64 ) 1000000000 );
-	            unit = "G";
+	            unit = _("G");
             }
             else
             {
                 val = ((gfloat)size) / ( ( guint64 ) 1 << 30 );
-                unit = "G";  //MOD was GiB
+                unit = _("G");  //MOD was GiB
             }
         }
     }
@@ -539,12 +598,12 @@ void vfs_file_size_to_string( char* buf, guint64 size )
 	    if (app_settings.use_si_prefix==TRUE)
 	    {
 	        val = ((gfloat)size) / (( guint64 ) 1000000 );
-	        unit = "M";
+	        unit = _("M");
         }
         else
         {
             val = ((gfloat)size) / ( ( guint64 ) 1 << 20 );
-            unit = "M";  //MOD was MiB
+            unit = _("M");  //MOD was MiB
         }
     }
     else if ( size > ( 1 << 10 ) )
@@ -557,18 +616,18 @@ void vfs_file_size_to_string( char* buf, guint64 size )
 	    if (app_settings.use_si_prefix==TRUE)
 	    {
 	        val = ((gfloat)size) / (( guint64 ) 1000 );
-	        unit = "K";  //MOD was KB
+	        unit = _("K");  //MOD was KB
 	    }
 	    else
 	    {
 	        val = ((gfloat)size) / ( ( guint64 ) 1 << 10 );
-            unit = "K";  //MOD was KiB
+            unit = _("K");  //MOD was KiB
 	    }
     }
     else
     {
         //unit = size > 1 ? "Bytes" : "Byte";
-        unit = "B";
+        unit = _("B");
         sprintf( buf, "%u %s", ( guint ) size, unit );
         return ;
     }
