@@ -27,11 +27,12 @@
 GdkPixbuf* vfs_load_icon( GtkIconTheme* theme, const char* icon_name, int size );
 
 /* execute programs with sudo */
+#ifdef HAVE_HAL
 gboolean vfs_sudo_cmd_sync( const char* cwd, char* argv[],
-                                               int* exit_status,
-                                               char** pstdout, char** pstderr, GError** err );  //MOD
-
-gboolean vfs_sudo_cmd_async( const char* cwd, char* argv[], GError** err );  //MOD
+                            int* exit_status,
+                            char** pstdout, char** pstderr, GError** err );  //MOD
 
+//gboolean vfs_sudo_cmd_async( const char* cwd, char* argv[], GError** err );  //MOD
+#endif
 
 #endif
